@@ -56,7 +56,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT"
-__version__: str = "0.4.0"
+__version__: str = "0.4.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
@@ -72,10 +72,10 @@ __all__ = [
 		]
 
 #: Regular expression to match default values declared in docstrings.
-default_regex: Pattern = re.compile(r"^:(default|Default) ")
+default_regex: Pattern = re.compile("^:(default|Default) ")
 
 #: Regular expression to match flags in docstrings to suppress default values.
-no_default_regex: Pattern = re.compile(r"^:(No|no)[-_](default|Default) ")
+no_default_regex: Pattern = re.compile("^:(No|no)[-_](default|Default) ")
 
 
 def escape_trailing__(string: str) -> str:
@@ -96,7 +96,7 @@ def format_default_value(value: Any) -> Optional[str]:
 
 	:param value:
 
-	.. versionadded:: 0.4.0
+	.. versionadded:: 0.4.1
 	"""
 
 	if value is not inspect.Signature.empty and value is not Ellipsis:
@@ -147,7 +147,7 @@ def process_docstring(
 		return None
 
 	# Size varies depending on docutils config
-	a_tab = " " * app.config.docutils_tab_width  # type: ignore
+	a_tab = ' ' * app.config.docutils_tab_width  # type: ignore
 
 	if callable(obj):
 
@@ -173,7 +173,7 @@ def process_docstring(
 			default_searchfor = re.compile(fr"^:[dD]efault {re.escape(argname)}:")
 			for i, line in enumerate(lines):
 				if default_searchfor.match(line):
-					formatted_annotation = ":".join(line.split(":")[2:]).lstrip()
+					formatted_annotation = ':'.join(line.split(':')[2:]).lstrip()
 					lines.remove(line)
 					break
 
@@ -202,7 +202,7 @@ def process_docstring(
 						if not line.startswith(a_tab):
 
 							# Ensure the previous line has a fullstop at the end.
-							line_content = ":".join(lines[insert_index + idx].split(":")[2:]).strip()
+							line_content = ':'.join(lines[insert_index + idx].split(':')[2:]).strip()
 							if line_content and line_content[-1] not in ".,;:":
 								lines[insert_index + idx] += '.'
 
@@ -251,8 +251,6 @@ def get_class_defaults(obj: Type) -> _defaults:
 
 		yield argname, default_value
 
-	return None
-
 
 def get_function_defaults(obj: Callable) -> _defaults:
 	"""
@@ -266,8 +264,6 @@ def get_function_defaults(obj: Callable) -> _defaults:
 	for argname, param in get_arguments(obj).items():
 		yield argname, param.default
 
-	return None
-
 
 def get_arguments(obj: Callable) -> Mapping[str, inspect.Parameter]:
 	"""
